use 5.006;
package Foo;
use Mo;
our $VERSION = 1;

=encoding utf8

=head1 NAME

Foo - for thought!

=head1 AUTHORS

Ingy döt Net <ingy@cpan.org>

=head1 COPYRIGHT AND LICENSE

Copyright (c) 2011. Ingy döt Net.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

See http://www.perl.com/perl/misc/Artistic.html

=cut
